translate.convert.csv2po

Package translate :: Package convert :: Module csv2po |
[hide private]
[frames] | no frames]

# Module csv2po

source code

convert Comma-Separated Value (.csv) files to Gettext PO localization files

See: http://translate.sourceforge.net/wiki/toolkit/csv2po for examples and usage instructions

Classes | [hide private]
| csv2po a class that takes translations from a .csv file and puts them in a .po file

Functions | [hide private]
replacestrings(source, *pairs) | source code
quotecsvstr(source) | source code
simplify(string) | source code
convertcsv(inputfile, outputfile, templatefile, charset=None, columnorder=None, duplicatestyle="msgctxt") reads in inputfile using csvl10n, converts using csv2po, writes to outputfile | source code
main(argv=None) | source code

Imports: sys, sparse, po, csvl10n